@@ -9,5 +9,5 @@ class PhononDispersions(TwoDimensionalPlotProperty):
     def __init__(self, name, parser, *args, **kwargs):
         super(PhononDispersions, self).__init__(name, parser, *args, **kwargs)
         phonon_dispersions = self.parser.phonon_dispersions()
-        self.xDataArray = phonon_dispersions['qpoints']
-        self.yDataSeries = phonon_dispersions['frequencies']
+        self.xDataArray = phonon_dispersions["qpoints"]
+        self.yDataSeries = phonon_dispersions["frequencies"]
