@@ -1,6 +1,7 @@
+# ruff: noqa: F403,F405
+from express.parsers.apps.nwchem.parser import NwchemParser
 from tests.fixtures.nwchem.references import *
 from tests.integration import IntegrationTestBase
-from express.parsers.apps.nwchem.parser import NwchemParser
 
 
 class TestNwchemParser(IntegrationTestBase):
@@ -9,7 +10,7 @@ class TestNwchemParser(IntegrationTestBase):
         self.parser = NwchemParser(work_dir=self.workDir, stdout_file=self.stdoutFile)
 
     def tearDown(self):
-        super(TestNwchemParser, self).setUp()
+        super(TestNwchemParser, self).tearDown()
 
     def test_nwchem_total_energy(self):
         self.assertAlmostEqual(self.parser.total_energy(), TOTAL_ENERGY, places=2)
