@@ -1,17 +1,16 @@
 import os
 
+from express.parsers.molecule import MoleculeParser
 from tests.fixtures.structural.references import INCHI_DATA
 from tests.integration import IntegrationTestBase
-from express.parsers.molecule import MoleculeParser
 
 
 class TestMoleculeParser(IntegrationTestBase):
-
     def setUp(self):
         super(IntegrationTestBase, self).setUp()
 
     def tearDown(self):
-        super(IntegrationTestBase, self).setUp()
+        super(IntegrationTestBase, self).tearDown()
 
     @property
     def parser(self):
@@ -20,7 +19,7 @@ class TestMoleculeParser(IntegrationTestBase):
             kwargs = {
                 "cell_type": manifest.get("cell_type", "original"),
                 "structure_string": f.read(),
-                "structure_format": "poscar"
+                "structure_format": "poscar",
             }
             return MoleculeParser(**kwargs)
 
