@@ -1,17 +1,16 @@
 import os
 
+from express.parsers.structure import StructureParser
 from tests.fixtures.data import SI
 from tests.integration import IntegrationTestBase
-from express.parsers.structure import StructureParser
 
 
 class TestStructureParser(IntegrationTestBase):
-
     def setUp(self):
         super(IntegrationTestBase, self).setUp()
 
     def tearDown(self):
-        super(IntegrationTestBase, self).setUp()
+        super(IntegrationTestBase, self).tearDown()
 
     @property
     def parser(self):
@@ -20,7 +19,7 @@ class TestStructureParser(IntegrationTestBase):
             kwargs = {
                 "structure_string": f.read(),
                 "cell_type": manifest.get("cell_type", "original"),
-                "structure_format": manifest.get("structureFormat", "poscar")
+                "structure_format": manifest.get("structureFormat", "poscar"),
             }
             return StructureParser(**kwargs)
 
