@@ -3,37 +3,11 @@ from tests.fixtures.data import PHONON_DISPERSIONS_RAW_DATA
 from express.properties.non_scalar.two_dimensional_plot.phonon_dispersions import PhononDispersions
 
 PHONON_DISPERSIONS = {
-    "yDataSeries": [
-        [
-            -6e-06,
-            -6.859784
-        ],
-        [
-            -6e-06,
-            -6.859784
-        ]
-    ],
-    "xDataArray": [
-        [
-            0.0,
-            0.0,
-            0.0
-        ],
-        [
-            0.0,
-            0.05,
-            0.05
-        ]
-    ],
+    "yDataSeries": [[-6e-06, -6.859784], [-6e-06, -6.859784]],
+    "xDataArray": [[0.0, 0.0, 0.0], [0.0, 0.05, 0.05]],
     "name": "phonon_dispersions",
-    "xAxis": {
-        "units": "crystal",
-        "label": "qpoints"
-    },
-    "yAxis": {
-        "units": "cm-1",
-        "label": "frequency"
-    }
+    "xAxis": {"units": "crystal", "label": "qpoints"},
+    "yAxis": {"units": "cm-1", "label": "frequency"},
 }
 
 
